@@ -25,7 +25,7 @@ class ColorizingStreamHandler(logging.StreamHandler):
         'white': 7,
     }
 
-    #levels to (background, foreground, bold/intense)
+    # levels to (background, foreground, bold/intense)
     level_map = {
         logging.DEBUG: (None, 'blue', False),
         logging.INFO: (None, 'white', False),
@@ -53,7 +53,7 @@ class ColorizingStreamHandler(logging.StreamHandler):
             self.flush()
         except (KeyboardInterrupt, SystemExit):
             raise
-        except:
+        except:  # noqa: E722
             self.handleError(record)
 
     def output_colorized(self, message):
@@ -118,7 +118,12 @@ class ReadableSqlFilter(logging.Filter):
     """
 
     def filter(self, record):
-        if record.sql[:6] != 'SELECT':
+        # Django 1.7 changed the way SQL got logged for some reason:
+        # https://code.djangoproject.com/ticket/17158
+        # https://github.com/django/django/commit/6605ac331a9e0
+        if 'SELECT' not in record.sql[:28]:
+            # WISHLIST what's the most performant way to see if 'SELECT' was
+            # used?
             return True
 
         # unfortunately, record.msg has already been rendered so we have to
@@ -127,8 +132,11 @@ class ReadableSqlFilter(logging.Filter):
         try:
             end = record.msg.index('FROM')
         except ValueError:  # not all SELECT statements also have a FROM
-            end = -1
-        if end - begin > 100:
-            record.msg = u'{0} ... {1}'.format(
-                record.msg[:begin + 6], record.msg[end:])
+            return True
+        try:
+            very_end = record.msg.rindex(u'; args') + 1
+        except ValueError:  # msg does not have "args" to strip
+            very_end = None
+        record.msg = u'{0} ... {1}'.format(
+            record.msg[:begin + 6], record.msg[end:very_end])
         return True
